@@ -31,7 +31,7 @@ from czmodel.util.postprocessing import add_postprocessing_layers
 # Ignore flake8 imported but unused warnings (does not recognize non-runtime check). Checked by mypy
 if TYPE_CHECKING:
     from tensorflow.keras import Model  # noqa: F401
-    from tensorflow.keras.layers import Layer  # noqa: F401
+    from tensorflow.keras.layers import Layer  # noqa: F401  # pylint: disable=no-name-in-module # Caused by TensorFlow
     from czmodel.model_metadata import ModelMetadata  # noqa: F401 # pylint: disable=C0412
 
 
