@@ -24,7 +24,11 @@ class RgbToBgr(tf.keras.layers.Layer):
     """A Keras pre-processing layer that converts RGB inputs to BGR color representation."""
 
     @tf.function
-    def call(self, inputs: "tf.Tensor", **kwargs: "Any") -> "tf.Tensor":
+    def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
+            self,
+            inputs: "tf.Tensor",
+            **kwargs: "Any"
+    ) -> "tf.Tensor":
         """Performs the RGB to BGR conversion.
 
         Args:
@@ -42,7 +46,11 @@ class RgbaToBgra(tf.keras.layers.Layer):
     """A Keras pre-processing layer that converts RGBA inputs to BGRA color representation."""
 
     @tf.function
-    def call(self, inputs: "tf.Tensor", **kwargs: "Any") -> "tf.Tensor":
+    def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
+            self,
+            inputs: "tf.Tensor",
+            **kwargs: "Any"
+    ) -> "tf.Tensor":
         """Performs the RGBA to BGRA conversion.
 
         Args:
@@ -60,7 +68,11 @@ class PerImageStandardization(tf.keras.layers.Layer):
     """A Keras pre-processing layer that applies per image standardization."""
 
     @tf.function
-    def call(self, inputs: "tf.Tensor", **kwargs: "Any") -> "tf.Tensor":
+    def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
+            self,
+            inputs: "tf.Tensor",
+            **kwargs: "Any"
+    ) -> "tf.Tensor":
         """Shifts and linearly scales each image.
 
          The image will have mean 0 and variance 1. The image is implicitly converted to float representation.
@@ -106,7 +118,11 @@ class Normalization(tf.keras.layers.Layer):
             )
 
     @tf.function
-    def call(self, inputs: "tf.Tensor", **kwargs: "Any") -> "tf.Tensor":
+    def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
+            self,
+            inputs: "tf.Tensor",
+            **kwargs: "Any"
+    ) -> "tf.Tensor":
         """Shifts and linearly scales an image by constant values.
 
         Args:
